pub struct FramePlanesMut<'a, T> { /* private fields */ }Expand description
Mutable borrowed Y/U/V plane slices stored behind stable raw pointers.
Implementations
Sourceimpl<'a, T> FramePlanesMut<'a, T>
impl<'a, T> FramePlanesMut<'a, T>
Sourcepub fn new(planes: [Option<&'a mut [T]>; 3]) -> Self
pub fn new(planes: [Option<&'a mut [T]>; 3]) -> Self
Creates a mutable plane set from optional Y, U, and V slices.
Sourcepub fn plane(&self, plane: usize) -> Result<&[T]>
pub fn plane(&self, plane: usize) -> Result<&[T]>
Returns an immutable view of the requested plane.
Sourcepub fn plane_mut(&mut self, plane: usize) -> Result<&mut [T]>
pub fn plane_mut(&mut self, plane: usize) -> Result<&mut [T]>
Returns a mutable view of the requested plane.
Sourcepub unsafe fn plane_split(&mut self, plane: usize) -> Result<(&[T], &mut [T])>
pub unsafe fn plane_split(&mut self, plane: usize) -> Result<(&[T], &mut [T])>
Returns immutable and mutable views over the same plane backing storage.
Safety
The caller must ensure the returned immutable and mutable slices are only used on non-overlapping logical regions of the same underlying plane.