#[repr(C)]pub struct MotionVector {
pub x: i32,
pub y: i32,
pub sad: i64,
}Expand description
One motion vector and its matching cost.
Fields
x: i32Horizontal displacement in subpixel units of the owning analysis level.
y: i32Vertical displacement in subpixel units of the owning analysis level.
sad: i64Matching cost associated with this vector.